@@ -18,9 +18,13 @@ sub options { (
 sub run {
     my ( $self, $lang ) = @_;
     my $logger = App::I18N->logger();
-    my $podir = $self->{podir} || 'po';
-
+    my $podir;
     $self->{mo} = $self->{locale} = 1 if $self->{gettext};
+    unless( $podir ) {
+        $podir = 'po' if -e 'po';
+        $podir = 'locale' if -e 'locale' && $self->{locale};
+        $podir ||= 'po';
+    }
 
     my @pofiles = File::Find::Rule->file->name( "*.po" )->in( $podir );
     for my $pofile ( @pofiles ) {
